@@ -237,6 +237,9 @@ class DebHelper:
         if $pkg is given, $dest will be created within it."""
         s = f"{pkg}/{src}" if pkg else src
         p = relpath(dest, src)
+        if p == "":
+            # src and dest are the same
+            return 
         cli.verbose_print(f"DEBUG ln -s {s} {p}")
         if islink(s):  # So symlink doesn't fail on idempotent
             unlink(s)
